@@ -31,16 +31,10 @@ for module in rest_settings['modules']:
         try:
             # Overwrite modules settings
             conf_mod = import_module(module['path_to_the_config'])
-
-            # conf = conf_mod.config
-            #conf_mod.config["settings"] = dict_merge(common_settings, conf_mod.config)
             conf_mod.config["settings"] = dict_merge(conf_mod.config, common_settings)
-
             conf_mod.config["settings"] = conf_mod.config["settings"]["settings"]
-            log.info(conf_mod.config["settings"])
         except Exception, e:
-            log.error(e)
-
+            log.warning(e)
 
         try:
             # Load module
@@ -51,11 +45,11 @@ for module in rest_settings['modules']:
 
             # Register Blueprint
             app.register_blueprint(rest, url_prefix=module['url_prefix'])
-            log.error("Module loaded: " + module['path_to_the_blueprint'])
+            log.info("Module loaded: " + module['path_to_the_blueprint'])
         except Exception, e:
-            log.error(e)
+            log.warning(e)
     except Exception, e:
-        log.error(e)
+        log.warning(e)
 
 @app.route('/')
 @cross_origin(origins='*')
@@ -83,6 +77,27 @@ def discovery():
     rules.sort()
     return Response(json.dumps(rules), content_type='application/json; charset=utf-8')
 
+
+@app.route('/discovery/service/url/name/<name>/')
+@cross_origin(origins='*')
+def discovery_by_name(name):
+    """
+    Discovery service url by name
+    @return: List the url to call the service
+    """
+    result = {}
+    for r in app.url_map.iter_rules():
+        rule_name = str(r)
+        if '.' in r.endpoint and rule_name.endswith('/') and 'discovery' in rule_name:
+            discovery_url = request.host_url + rule_name[1:]
+            print discovery_url
+            plugin_description = json.load(urllib2.urlopen(discovery_url))
+            if "name" in plugin_description:
+                if plugin_description["name"] == name:
+                    result["url"] = (request.host_url + rule_name[1:]).replace("discovery/", "")
+    return Response(json.dumps(result), content_type='application/json; charset=utf-8')
+
+
 @app.route('/discovery/<type>/')
 @cross_origin(origins='*')
 def discovery_by_type(type):
@@ -104,5 +119,4 @@ def discovery_by_type(type):
 
 # Start Flask server
 if __name__ == '__main__':
-    print rest_settings
     app.run(host=rest_settings['host'], port=rest_settings['port'], debug=rest_settings['debug'], threaded=True)
\ No newline at end of file
